@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-4401e245d4ad353101495ec7ffae051c
-key: vecto_DhnjAOTuHMUJxkIlq7ZWEg
+id: vector-instances-3.3.1-b06c64eca876b2bde276809d07840573
+key: vecto_Az84Iak3JmYKyGzEsrZjVC
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,15 +17,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-DhnjAOTuHMUJxkIlq7ZWEg
+hs-libraries: HSvector-instances-3.3.1-Az84Iak3JmYKyGzEsrZjVC
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-ef08fcd44c0efc29fa5bad32641dc22e
-    keys-3.11-0b36ec2e8f3424fb442baf31706441a6
-    pointed-5-6c8ff5d654d1b392d4ea0e2479250ddd
-    semigroupoids-5.0.1-8962f0a8eeeddfa137860cecf2c3229e
-    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
-    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
+    comonad-5-caa084d849f0fd836e529854caff7fc2
+    keys-3.11-3d8e7ac6dad4b2be59ab23649a19b0c5
+    pointed-5-517604c53148c16ee342915b24abeef1
+    semigroupoids-5.0.1-71b3eb635555631c006bdf0054367a98
+    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
 haddock-html: /usr/share/doc/haskell-vector-instances/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
